#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 7/10/22

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from gimpfu import *
import os, sys,time
import gettext
gettext.install("gimp20", gimp.locale_directory, unicode=True)

def pm_create_memo_board_ver_3(changeColor, pcolor, color_note_slip):

    #Initiates the temporary state
    pdb.gimp_context_push()
    pdb.gimp_context_set_defaults()
    
    #Create the cork texture
    size = 1000
    img = pdb.gimp_image_new(size, size, RGB)
    corkLayer = pdb.gimp_layer_new(img, size, size, RGBA_IMAGE, "Cork", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, corkLayer, None, 0)
    pdb.gimp_context_set_foreground((220, 200, 154))
    pdb.gimp_drawable_fill(corkLayer, FILL_FOREGROUND)

    #Image process
    pdb.gimp_display_new(img)
    
    pdb.plug_in_hsv_noise(img, corkLayer, 4, 0, 230, 200)
    pdb.plug_in_gmic_qt(img, corkLayer, 1, 0, "-fx_crystal 50,2,50,0,50,50")
    pdb.gimp_drawable_hue_saturation(corkLayer, ALL_HUES, 0, 10, 100, 0)
    pdb.gimp_drawable_hue_saturation(corkLayer, ALL_HUES, 0, 50, 100, 0)
    pdb.gimp_drawable_hue_saturation(corkLayer, ALL_HUES, -10, 0, 100, 0)
    pdb.gimp_image_crop(img, 900, 600, 0, 0)
    pdb.gimp_layer_resize_to_image_size(corkLayer)
        
    #Create a new image
    size = 900
    woodLayer = pdb.gimp_layer_new(img, size, size, RGB_IMAGE, "Wood pattern", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, woodLayer, 0)
    pdb.gimp_context_set_foreground((220, 180, 134))
    pdb.gimp_drawable_fill(woodLayer, FILL_FOREGROUND)
    
    #Create the noise layer
    cloudLayer = pdb.gimp_layer_new(img, size, size, RGB_IMAGE, "Noise cloud", 100, LAYER_MODE_SOFTLIGHT)
    pdb.gimp_image_add_layer(img, cloudLayer, 0)
    pdb.gimp_layer_add_alpha(cloudLayer)
    pdb.gimp_drawable_fill(cloudLayer, FILL_TRANSPARENT)
    pdb.plug_in_solid_noise(img, cloudLayer, FALSE, FALSE, 0, 15, 2, 2)
    
    #Create the design
    woodLayer = pdb.gimp_image_merge_down(img, cloudLayer, CLIP_TO_IMAGE)
    pdb.gimp_item_set_name(woodLayer, "Frame")
    pdb.plug_in_ripple(img, woodLayer, 320, 800, 0, 1, 1, TRUE, TRUE)    
    pdb.plug_in_hsv_noise(img, woodLayer, 8, 2, 4, 255)
    pdb.plug_in_wind(img, woodLayer, 15, 0, 45, 0, 0)
    pdb.plug_in_wind(img, woodLayer, 15, 1, 45, 0, 0)
    pdb.plug_in_make_seamless(img, woodLayer)
    
    copy = pdb.gimp_layer_new_from_drawable(woodLayer, img)
    pdb.gimp_image_insert_layer(img, copy, None, 0)
    pdb.gimp_layer_set_mode(copy, LAYER_MODE_NORMAL)
    pdb.gimp_layer_set_opacity(copy, 100)
        
############## Create the base frame ###########################
    frameW = pdb.gimp_image_width(img)
    freameH = pdb.gimp_image_height(img)
    pdb.gimp_image_select_round_rectangle(img, 2, 0, 0, frameW, freameH, 45, 45)
    pdb.gimp_selection_invert(img)
    pdb.gimp_drawable_edit_clear(woodLayer)
    pdb.gimp_drawable_edit_clear(corkLayer)
    pdb.gimp_selection_none(img)
    pdb.gimp_image_select_item(img, 2, corkLayer)   
    pdb.gimp_selection_shrink(img, 45)
    pdb.gimp_drawable_edit_clear(woodLayer)
    pdb.gimp_selection_none(img)
    
    copy = pdb.gimp_item_transform_rotate_simple(copy, ROTATE_90 , TRUE, 0, 0)
    pdb.gimp_layer_scale(copy, 900, 900, TRUE)
    pdb.gimp_layer_resize_to_image_size(copy)
    pdb.gimp_image_select_item(img, 2, woodLayer)
    pdb.gimp_selection_invert(img)
    pdb.gimp_drawable_edit_clear(copy)
    pdb.gimp_image_lower_item(img, copy)
    
    pdb.gimp_image_select_rectangle(img, 2, 45, 0, 820, 45)
    pdb.gimp_drawable_edit_clear(copy)
    pdb.gimp_selection_none(img)
    pdb.gimp_image_select_rectangle(img, 2, 45, 555, 820, 45)
    pdb.gimp_drawable_edit_clear(copy)
    pdb.gimp_selection_none(img)
    
    pdb.gimp_image_select_rectangle(img, 2, 0, 45, 50, 510)
    pdb.gimp_drawable_edit_clear(woodLayer)
    pdb.gimp_selection_none(img)
    pdb.gimp_image_select_rectangle(img, 2, 855, 45, 45, 510)
    pdb.gimp_drawable_edit_clear(woodLayer)
    pdb.gimp_selection_none(img)
    
    Black = "#000000"
    White = "#ffffff"
    pdb.python_layerfx_bevel_emboss(img, copy,
                                            1,    #style inner bevel
                                           65,   #depth
                                            0,   #direction
                                            7,   #size
                                           12,   #soften
                                           90,   #angle
                                           35,   #altitude
                                            0,   #glos_contour -linear
                                      (White),   #highlight_color
                                            4,   #highlight_mode lighten only
                                           75,   #highlight_opacity
                                      (Black),   #shadow_color
                                            3,   #shadow_mode burn
                                           35,   #shadow_opacity
                                            0,   #surface_contour - linear
                                        FALSE,   #use_texture
                                   "Dried mud",  #pattern
                                          100,   #scale
                                          100,   #tex_depth
                                         TRUE,   #invert
                                         TRUE)   #merge   
    
    pdb.python_layerfx_bevel_emboss(img, woodLayer,
                                                 1,    #style inner bevel
                                                65,   #depth
                                                 0,   #direction
                                                 7,   #size
                                                12,   #soften
                                                 0,   #angle
                                                35,   #altitude
                                                 0,   #glos_contour -linear
                                           (White),   #highlight_color
                                                 4,   #highlight_mode lighten only
                                                75,   #highlight_opacity
                                           (Black),   #shadow_color
                                                 3,   #shadow_mode burn
                                                35,   #shadow_opacity
                                                 0,   #surface_contour - linear
                                             FALSE,   #use_texture
                                        "Dried mud",  #pattern
                                               100,   #scale
                                               100,   #tex_depth
                                              TRUE,   #invert
                                              TRUE)   #merge   
    
    
    woodLayer = pdb.gimp_image_merge_visible_layers(img, EXPAND_AS_NECESSARY)
    woodLayer = pdb.gimp_image_get_layer_by_name(img, "Cork")
    pdb.gimp_item_set_name(woodLayer, "Frame")
    
    #Create the note slip
    noteLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Note slip", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, noteLayer, None, 0)
    pdb.gimp_drawable_fill(noteLayer, FILL_TRANSPARENT)
	#pdb.gimp_context_set_foreground((248, 225, 120))	# MrQ
    pdb.gimp_context_set_foreground(color_note_slip)	# MrQ
    pdb.gimp_brushes_set_brush("2. Block 01")
    pdb.gimp_context_set_brush_size(200)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(5.00)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(noteLayer, 2, [450, 300])
    
    #Note slip bent
    pdb.plug_in_ripple(img, noteLayer, 240, 5, 1, 1, 1, TRUE, TRUE)
    
    #Note drop shadow
    color = "#000000"
    opacity = 75.0
    contour = 0
    noise = 0.0
    mode = 3           #LAYER_MODE_MULTIPLY_LEGACY
    spread = 0
    size = 8
    offsetangle = 145.0
    offsetdist = 8.0
    knockout = TRUE
    merge = TRUE
    pdb.python_layerfx_drop_shadow(img, noteLayer, color, opacity, contour, noise, mode, spread, size, offsetangle, offsetdist, knockout, merge)
    noteLayer = pdb.gimp_image_get_layer_by_name(img, "Note slip")
    
    #Slip gradient overlay
    pdb.gimp_context_set_foreground((255, 220, 60))
    pdb.gimp_context_set_background((52, 45, 10))
    gradient = _("FG to BG (RGB)")	#MrQ
    gradienttype = 1
    repeat = 0
    reverse = 1
    opacity = 50.0
    mode = 5                #LAYER_MODE_OVERLAY_LEGACY
    centerx = 450
    centery = 250
    angle = 175.0
    width = 100.0
    merge = 1
    pdb.python_layerfx_gradient_overlay(img, noteLayer, gradient, gradienttype, repeat, reverse, opacity, mode, centerx, centery, angle, width, merge)
    noteLayer = pdb.gimp_image_get_layer_by_name(img, "Note slip")
    pdb.gimp_layer_resize_to_image_size(noteLayer)
    
######################### Create the Push pin ###################################
    
    new_size = 310
    pinLayer = pdb.gimp_layer_new(img, new_size, new_size, RGBA_IMAGE, "Bottom", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, pinLayer, None, 0)
    pdb.gimp_drawable_fill(pinLayer, FILL_TRANSPARENT)
    
    #Create the pins bottom
    pdb.gimp_context_set_foreground((206, 3, 0))
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(140)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(24.00)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(pinLayer, 2, [96, 117])
    
    #Pin drop shadow
    color = "#000000"
    opacity = 75.0
    contour = 0
    noise = 0.0
    mode = 3           #LAYER_MODE_MULTIPLY_LEGACY
    spread = 0
    size = 10
    offsetangle = 145.0
    offsetdist = 8.0
    knockout = TRUE
    merge = FALSE
    pdb.python_layerfx_drop_shadow(img, pinLayer, color, opacity, contour, noise, mode, spread, size, offsetangle, offsetdist, knockout, merge)
    
    #Pin bottom inner glow
    color = "#ab0000"
    opacity = 75.0
    contour = 0
    noise = 0.0
    mode =0             #LAYER_MODE_NORMAL_LEGACY
    source = 1
    choke = 0.0
    size = 8
    merge = 0
    pdb.python_layerfx_inner_glow(img, pinLayer, color, opacity, contour, noise, mode, source, choke, size, merge)
 
    #Middle ring shadow
    ringShad = pdb.gimp_layer_new(img, new_size, new_size, RGBA_IMAGE, "Ring shadow", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, ringShad, None, 0)
    pdb.gimp_drawable_fill(ringShad, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((89, 0, 0))
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(75)
    pdb.gimp_context_set_brush_aspect_ratio(-0.10)
    pdb.gimp_context_set_brush_angle(40.00)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(ringShad, 2, [90, 104])
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(70)
    pdb.gimp_context_set_brush_aspect_ratio(-0.10)
    pdb.gimp_context_set_brush_angle(40.00)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_eraser_default(ringShad, 2, [90, 104])
    pdb.plug_in_gauss(img, ringShad, 8, 8, 1)
    
    #Middle form
    midForm = pdb.gimp_layer_new(img, new_size, new_size, RGBA_IMAGE, "Midform", 100, LAYER_MODE_DODGE_LEGACY)
    pdb.gimp_image_insert_layer(img, midForm, None, 0)
    pdb.gimp_drawable_fill(midForm, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((89, 0, 0))
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(70)
    pdb.gimp_context_set_brush_aspect_ratio(0.30)
    pdb.gimp_context_set_brush_angle(24.00)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(midForm, 2, [80, 95])
    pdb.plug_in_gauss(img, midForm, 28, 28, 1)
    
    #Top shadow
    topShad = pdb.gimp_layer_new(img, new_size, new_size, RGBA_IMAGE, "Top shadow", 85, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, topShad, None, 0)
    pdb.gimp_drawable_fill(topShad, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((64, 0, 0))
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(120)
    pdb.gimp_context_set_brush_aspect_ratio(0.40)
    pdb.gimp_context_set_brush_angle(30.00)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(topShad, 2, [105, 120])
    pdb.plug_in_gauss(img, topShad, 30, 30, 1)
    
    #Pin top
    pinTop = pdb.gimp_layer_new(img, new_size, new_size, RGBA_IMAGE, "Top", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, pinTop, None, 0)
    pdb.gimp_drawable_fill(pinTop, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((212, 47, 0))
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(105)
    pdb.gimp_context_set_brush_aspect_ratio(-0.10)
    pdb.gimp_context_set_brush_angle(24.00)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(pinTop, 2, [53, 64])
    
    #Pin bottom inner glow
    color = "#a42107"
    opacity = 75.0
    contour = 0
    noise = 0.0
    mode =0             #LAYER_MODE_MULTIPLY_LEGACY
    source = 1
    choke = 0.0
    size = 60
    merge = 0
    pdb.python_layerfx_inner_glow(img, pinTop, color, opacity, contour, noise, mode, source, choke, size, merge)
    
    #Pin bottom inner glow
    color = "#f20703"
    opacity = 100.0
    contour = 0
    noise = 0.0
    mode =0             #LAYER_MODE_NORMAL_LEGACY
    source = 1
    choke = 20.0
    size = 40
    merge = 0
    pdb.python_layerfx_inner_glow(img, pinTop, color, opacity, contour, noise, mode, source, choke, size, merge)
    
    #Bottom light reflection
    refLayer2 = pdb.gimp_layer_new(img, new_size, new_size, RGBA_IMAGE, "Top light reflection", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, refLayer2, None, 0)
    pdb.gimp_drawable_fill(refLayer2, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground("White")
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(10)
    pdb.gimp_context_set_brush_aspect_ratio(-1.00)
    pdb.gimp_context_set_brush_angle(34.00)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_paintbrush_default(refLayer2, 2, [25, 40])
    pdb.plug_in_mblur(img, refLayer2, 1, 5, 20, 60, 65)
            
    #Merge the Pin effects layers
    pdb.gimp_item_set_visible(woodLayer, FALSE)
    pdb.gimp_item_set_visible(noteLayer, FALSE)
    pinLayer = pdb.gimp_image_merge_visible_layers(img, EXPAND_AS_NECESSARY)
    pdb.gimp_layer_resize_to_image_size(pinLayer)
    pdb.gimp_item_set_name(pinLayer, "Pin")

    W = pdb.gimp_image_width(img)
    H = pdb.gimp_image_height(img)
    off_x = 360 
    off_y = 130
    #Scale down the pin and move to top middle
    pdb.gimp_item_set_visible(woodLayer, TRUE)
    pdb.gimp_item_set_visible(noteLayer, TRUE)
    pdb.gimp_image_select_rectangle(img, 2, 0, 0, 310, 310)
    pdb.plug_in_autocrop_layer(img, pinLayer)
    pdb.gimp_selection_none(img)
    pinLayer = pdb.gimp_item_transform_translate(pinLayer, off_x, off_y)
    pdb.gimp_layer_scale(pinLayer, 30, 30, TRUE)
    
    #Pin perspective shadow
    angle = -180
    shadow_angle = angle/180.0 * math.pi
    headPersp = pdb.gimp_layer_new_from_drawable(pinLayer, img)
    pdb.gimp_image_insert_layer(img, headPersp, None, 1)
    pdb.gimp_layer_set_mode(headPersp, LAYER_MODE_NORMAL)
    pdb.gimp_layer_set_opacity(headPersp, 80)
    pdb.gimp_context_set_foreground((0, 0, 0))
    pdb.gimp_drawable_edit_clear(headPersp)
    pdb.gimp_image_select_item(img, 2, pinLayer)
    pdb.gimp_drawable_edit_fill(headPersp, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    pdb.gimp_drawable_offset(headPersp, FALSE, 1, 2, 2)
    
    pinPersp = pdb.gimp_layer_new_from_drawable(pinLayer, img)
    pdb.gimp_image_insert_layer(img, pinPersp, None, 1)
    pdb.gimp_layer_set_mode(pinPersp, LAYER_MODE_NORMAL)
    pdb.gimp_layer_set_opacity(pinPersp, 80)
    pdb.gimp_drawable_edit_clear(pinPersp)
    pdb.gimp_image_select_item(img, 2, pinLayer)
    pdb.gimp_selection_shrink(img, 1)
    pdb.gimp_drawable_edit_fill(pinPersp, FILL_FOREGROUND)
    pdb.gimp_selection_none(img)
    pinPersp = pdb.gimp_item_transform_rotate(pinPersp, shadow_angle, TRUE, 0, 0)
    pdb.gimp_drawable_offset(pinPersp, FALSE, 1, 0, 2)
    pdb.gimp_drawable_offset(pinPersp, FALSE, 1, 2, 1)
    headPersp = pdb.gimp_image_merge_down(img, pinPersp, CLIP_TO_IMAGE)
    
    #Layer to image size all
    layer = 0
    layerlist = img.layers
    processlist=[]
    for layer in img.layers: 
        layer.resize_to_image_size()
    
    pdb.plug_in_gauss(img, headPersp, 2, 2, 1)
    pdb.gimp_item_set_name(headPersp, "Pin Shadow")
    pdb.gimp_layer_set_opacity(headPersp, 60)
    
    #Color option
    if changeColor==1:
        colorLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color", 100, LAYER_MODE_HSL_COLOR)
        pdb.gimp_image_insert_layer(img, colorLayer, None, 0)
        pdb.gimp_image_select_item(img, 2, pinLayer)
        pdb.gimp_context_set_foreground(pcolor)        
        pdb.gimp_drawable_fill(colorLayer, FILL_FOREGROUND)
        pdb.gimp_selection_none(img)
        pinLayer = pdb.gimp_image_merge_down(img, colorLayer, CLIP_TO_IMAGE)
    
    pdb.gimp_image_set_active_layer(img, woodLayer)
    
    #Resets the previous user defaults
    pdb.gimp_context_pop()	
	
register(
    "pm_create_memo_board_ver_3",
    "Creates a memo board",
    "Creates a memo board",
    "Pocholo",
    "Pocholo",
    "2022",
    "Memo Board V.3",
    "",
    [
    (PF_TOGGLE, "changeColor", "Channge Pin Color?", 0),
    (PF_COLOR, "pcolor", "Pin Color:", (6, 0, 122)),
    (PF_COLOR, "color_note_slip", "Note Slip Color:", (248, 225, 120)),	
    ],
    [],
    pm_create_memo_board_ver_3, menu="<Image>/Pocholo's-Plugins",
    domain=("gimp20", gimp.locale_directory))
main()	